## Methodology

This section covers different methods for implementing 
[Neighborhood Attention](https://openaccess.thecvf.com/content/CVPR2023/html/Hassani_Neighborhood_Attention_Transformer_CVPR_2023_paper.html)
.

* [BMM-style](bmm.md)
* [Fused](fused.md)

For more details, we highly recommend reading our papers:

* Neighborhood Attention Transformer | [Paper](https://arxiv.org/abs/2204.07143) | [Video](https://www.youtube.com/watch?v=Ya4BfioxIHA)
* Faster Neighborhood Attention | [Preprint](https://arxiv.org/abs/2403.04690)
